"""A package contaning additional RBM-based models (networks) for all common learnergy modules.
"""

from learnergy.models.extra.sigmoid_rbm import SigmoidRBM, SigmoidRBM4Deep
